View source: R/print.pbayesdecisionprob1cont.R
| print.pbayesdecisionprob1cont | R Documentation |
Displays a formatted summary of Go/NoGo/Gray decision probabilities
for continuous endpoint results returned by pbayesdecisionprob1cont.
## S3 method for class 'pbayesdecisionprob1cont'
print(x, digits = 4, ...)
x |
An object of class |
digits |
A positive integer specifying the number of decimal places for probability values. Default is 4. |
... |
Further arguments passed to or from other methods (ignored). |
Invisibly returns x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.